import { dim } from "kleur/colors";
import { performance } from "node:perf_hooks";
import { contentObservable, createContentTypesGenerator } from "../../content/index.js";
import { getTimeStat } from "../../core/build/util.js";
import { AstroError, AstroErrorData } from "../../core/errors/index.js";
import { info } from "../../core/logger/core.js";
import { setUpEnvTs } from "../../vite-plugin-inject-env-ts/index.js";
async function sync(settings, { logging, fs }) {
  const timerStart = performance.now();
  try {
    const contentTypesGenerator = await createContentTypesGenerator({
      contentConfigObserver: contentObservable({ status: "loading" }),
      logging,
      fs,
      settings
    });
    const typesResult = await contentTypesGenerator.init();
    if (typesResult.typesGenerated === false) {
      switch (typesResult.reason) {
        case "no-content-dir":
        default:
          info(logging, "content", "No content directory found. Skipping type generation.");
          return 0;
      }
    }
  } catch (e) {
    throw new AstroError(AstroErrorData.GenerateContentTypesError);
  }
  info(logging, "content", `Types generated ${dim(getTimeStat(timerStart, performance.now()))}`);
  await setUpEnvTs({ settings, logging, fs });
  return 0;
}
export {
  sync
};
